==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/sv.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Hantera ljus gallary Parametrar");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "chef för Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Bild i full storlek Bredd");
define('MANAGE_GALLERY_FULL_HEIGHT', "Bild i full storlek Höjd");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatyr Bredd");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatyr Höjd");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bevara Thumb Bildförhållande");
define('MANAGE_GALLERY_SHOW_TITLES', "Visa Titlar");
define('MANAGE_GALLERY_DISABLE_SORT', "Inaktivera Sortera");
define('MANAGE_GALLERY_DELETE_IMAGE', "Radera Bild");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Spara sorteringsordning");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klicka på &quot;Uppdatera&quot; för att publicera <br /> dina bilder upplagda.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alla bilder har storlek och inställningar har sparats.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Det gick inte att ändra storlek på bilderna eller spara inställningar.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Din bild (s) har överförts.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Det gick inte att överföra bilden (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Filen du försöker ladda upp är inte en bild.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Filen du försöker ladda upp är för stor.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titeln har sparats.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Är du säker på att du vill ta bort bilden");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Bilden har tagits bort.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Det gick inte att ta bort bilden.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Spara parametrar och ändra storlek på bilder, var god vänta ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uppladdning, var god vänta ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Sorteringsordningen har inte sparats. Vill du spara sorteringsordning?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Bildsorteringsordning har sparats.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Det uppstod ett fel när bilden sparades slag.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/sv.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Hantera ljus gallary Parametrar");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "chef för Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Bild i full storlek Bredd");
define('MANAGE_GALLERY_FULL_HEIGHT', "Bild i full storlek Höjd");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatyr Bredd");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatyr Höjd");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bevara Thumb Bildförhållande");
define('MANAGE_GALLERY_SHOW_TITLES', "Visa Titlar");
define('MANAGE_GALLERY_DISABLE_SORT', "Inaktivera Sortera");
define('MANAGE_GALLERY_DELETE_IMAGE', "Radera Bild");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Spara sorteringsordning");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klicka på &quot;Uppdatera&quot; för att publicera <br /> dina bilder upplagda.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alla bilder har storlek och inställningar har sparats.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Det gick inte att ändra storlek på bilderna eller spara inställningar.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Din bild (s) har överförts.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Det gick inte att överföra bilden (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Filen du försöker ladda upp är inte en bild.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Filen du försöker ladda upp är för stor.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titeln har sparats.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Är du säker på att du vill ta bort bilden");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Bilden har tagits bort.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Det gick inte att ta bort bilden.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Spara parametrar och ändra storlek på bilder, var god vänta ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uppladdning, var god vänta ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Sorteringsordningen har inte sparats. Vill du spara sorteringsordning?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Bildsorteringsordning har sparats.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Det uppstod ett fel när bilden sparades slag.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Filen du försöker ladda upp är större än PHP-inställningarna &#39;upload_max_filesize&#39; eller &#39;post_max_size&#39;. Kontakta din systemadministratör för att öka dessa gränser.");
?>
